
lz4 package
===========

Most of the functionality of this package is found in the :py:mod:`lz4.frame`
and the :py:mod:`lz4.block` sub-packages.

Contents
--------

.. automodule:: lz4
    :members:
       library_version_number,
       library_version_string,
       lz4version,
       version

